@@ -30,6 +30,14 @@ public interface GuidedDecisionTableConstants
     String COLON = ":";
 
     //Decision Table
+    String ExecuteWorkItemActions();
+
+    String RetractActions();
+
+    String BrlActions();
+
+    String BrlConditions();
+
     String NoPatternBindingsAvailable();
 
     String OtherwiseCellLabel();
@@ -114,9 +122,7 @@ public interface GuidedDecisionTableConstants
 
     String Options();
 
-    String EditThisActionColumnConfiguration();
-
-    String DeleteActionColumnWarning(String p0);
+    String DeleteColumnWarning(String p0);
 
     String NewColumn();
 
@@ -124,7 +130,9 @@ public interface GuidedDecisionTableConstants
 
     String Attribute();
 
-    String EditThisColumnsConfiguration();
+    String EditThisColumnConfiguration();
+
+    String DeleteThisColumn();
 
     String UnableToDeletePatterns();
 
@@ -132,8 +140,6 @@ public interface GuidedDecisionTableConstants
 
     String UnableToDeleteConditionColumn0(String p0);
 
-    String DeleteConditionColumnWarning0(String p0);
-
     String UseRowNumber();
 
     String ReverseOrder();
@@ -213,6 +219,8 @@ public interface GuidedDecisionTableConstants
     //Wizard
     String UseWizardToBuildAsset();
 
+    String UseWizardTooltip();
+
     String DecisionTableWizard();
 
     String DecisionTableWizardSummary();
@@ -326,20 +334,32 @@ public interface GuidedDecisionTableConstants
 
     String HitPolicy();
 
+    String HitPolicyTooltip();
+
     String NoneHitPolicy();
 
+    String NoneHitPolicyDescription();
+
     String UniqueHitPolicy();
 
+    String UniqueHitPolicyDescription();
+
     String FirstHitPolicy();
 
+    String FirstHitPolicyDescription();
+
     String RuleOrderHitPolicy();
 
+    String RuleOrderHitPolicyDescription();
+
     String None();
 
     String HasPriorityOverRow();
 
     String ResolvedHitPolicy();
 
+    String ResolvedHitPolicyDescription();
+
     String NoColumnsAvailable();
 
     String AddColumn();
