@@ -57,6 +57,7 @@ import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEdito
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.ext.wires.core.grids.client.model.Bounds;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.BaseGridWidgetKeyboardHandler;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationEditCell;
@@ -241,11 +242,24 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
                 activeDecisionTable = null;
             }
             dtPresenter.onClose();
+
+            removeLinksForDecisionTable(dtPresenter);
         };
         view.removeDecisionTable(dtPresenter.getView(),
                                  afterRemovalCommand);
     }
 
+    void removeLinksForDecisionTable(final GuidedDecisionTableView.Presenter dtPresenter) {
+        getAvailableDecisionTables()
+                .stream()
+                .map(other -> other.getView().getModel().getColumns())
+                .forEach(columns -> columns
+                        .stream()
+                        .filter(GridColumn::isLinked)
+                        .filter(column -> dtPresenter.getView().getModel().getColumns().contains(column.getLink()))
+                        .forEach(column -> column.setLink(null)));
+    }
+
     @Override
     public void onLockStatusUpdated(final GuidedDecisionTableView.Presenter dtPresenter) {
         if (dtPresenter == null) {
@@ -336,6 +350,16 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         return view.getGridLayerView().getDefaultTransformMediator();
     }
 
+    @Override
+    public void addOnEnterPinnedModeCommand(final Command command) {
+        view.getGridLayerView().addOnEnterPinnedModeCommand(command);
+    }
+
+    @Override
+    public void addOnExitPinnedModeCommand(final Command command) {
+        view.getGridLayerView().addOnExitPinnedModeCommand(command);
+    }
+
     @Override
     public void onDecisionTableSelected(final @Observes DecisionTableSelectedEvent event) {
         final Optional<GuidedDecisionTableView.Presenter> dtPresenter = event.getPresenter();
@@ -389,11 +413,20 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         if (isGridPinned()) {
             view.getGridLayerView().flipToGridWidget(dtPresenter.getView());
         }
+
+        handlePermissions(dtPresenter);
+    }
+
+    void handlePermissions(final GuidedDecisionTableView.Presenter dtPresenter) {
+        if (dtPresenter.hasEditableColumns()) {
+            view.enableColumnOperationsMenu();
+        }
     }
 
     void refreshDefinitionsPanel(final GuidedDecisionTableView.Presenter dtPresenter) {
         final GuidedDecisionTable52 model = dtPresenter.getModel();
-        view.setEnableColumnCreation(dtPresenter.getAccess().isEditable());
+
+        view.setEnableColumnCreation(isColumnCreationEnabled(dtPresenter));
         view.refreshAttributeWidget(model.getAttributeCols());
         view.refreshMetaDataWidget(model.getMetadataCols());
         view.refreshConditionsWidget(model.getConditions());
@@ -401,6 +434,26 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         view.refreshColumnsNote(dtPresenter.hasColumnDefinitions());
     }
 
+    boolean isColumnCreationEnabled(final GuidedDecisionTableView.Presenter dtPresenter) {
+
+        final boolean decisionTableIsEditable = !dtPresenter.isReadOnly();
+        final boolean decisionTableHasEditableColumns = dtPresenter.hasEditableColumns();
+
+        return decisionTableHasEditableColumns && decisionTableIsEditable;
+    }
+
+    @Override
+    public boolean isColumnCreationEnabledToActiveDecisionTable() {
+
+        final Optional<GuidedDecisionTableView.Presenter> decisionTable = Optional.ofNullable(getActiveDecisionTable());
+
+        if (!decisionTable.isPresent()) {
+            return false;
+        }
+
+        return isColumnCreationEnabled(decisionTable.get());
+    }
+
     @Override
     public void onDecisionTableLinkedColumnSelected(final @Observes DecisionTableColumnSelectedEvent event) {
         if (event.getColumn() == null) {
@@ -460,6 +513,11 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
                                                       isPinned));
     }
 
+    @Override
+    public void refreshScrollPosition() {
+        view.refreshScrollPosition();
+    }
+
     @Override
     public void updateLinks() {
         for (GuidedDecisionTableView.Presenter dtPresenter : getAvailableDecisionTables()) {
