@@ -3,7 +3,9 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 import javax.annotation.PostConstruct;
 import javax.inject.Inject;
 
@@ -18,39 +20,42 @@ import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.event.dom.client.ContextMenuEvent;
 import com.google.gwt.event.dom.client.ContextMenuHandler;
 import com.google.gwt.event.dom.client.KeyDownHandler;
+import com.google.gwt.event.dom.client.MouseDownEvent;
 import com.google.gwt.event.dom.client.MouseDownHandler;
+import com.google.gwt.event.dom.client.ScrollEvent;
 import com.google.gwt.event.shared.HandlerRegistration;
 import com.google.gwt.uibinder.client.UiBinder;
 import com.google.gwt.uibinder.client.UiField;
 import com.google.gwt.user.client.Command;
-import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.ui.Anchor;
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.FlowPanel;
 import com.google.gwt.user.client.ui.HasVerticalAlignment;
 import com.google.gwt.user.client.ui.HorizontalPanel;
 import com.google.gwt.user.client.ui.Label;
+import com.google.gwt.user.client.ui.RootPanel;
 import com.google.gwt.user.client.ui.VerticalPanel;
 import com.google.gwt.user.client.ui.Widget;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.BRLConditionColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.CompositeColumn;
-import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.screens.guided.dtable.client.resources.GuidedDecisionTableResources;
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableConstants;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.accordion.GuidedDecisionTableAccordion;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.accordion.GuidedDecisionTableAccordionItem;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.control.AttributeColumnConfigRow;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.control.ColumnLabelWidget;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.control.ColumnManagementView;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.control.DeleteColumnManagementAnchorWidget;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.ColumnUtilities;
+import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.common.DecisionTableColumnViewUtils;
 import org.gwtbootstrap3.client.ui.Button;
 import org.gwtbootstrap3.client.ui.CheckBox;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.widgets.client.ruleselector.RuleSelector;
-import org.uberfire.ext.widgets.common.client.common.SmallLabel;
 import org.uberfire.ext.wires.core.grids.client.model.Bounds;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
@@ -60,7 +65,6 @@ import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLienzoPane
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.GridPinnedModeManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.TransformMediator;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.impl.RestrictedMousePanMediator;
-import org.uberfire.mvp.ParameterizedCommand;
 
 public class GuidedDecisionTableModellerViewImpl extends Composite implements GuidedDecisionTableModellerView {
 
@@ -89,14 +93,8 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
             Scheduler.get().scheduleDeferred(new Scheduler.ScheduledCommand() {
                 @Override
                 public void execute() {
-                    final int width = getParent().getOffsetWidth();
-                    final int height = getParent().getOffsetHeight();
-                    if ((width != 0) && (height != 0)) {
-                        domElementContainer.setPixelSize(width,
-                                                         height);
-                        lienzoPanel.setPixelSize(width,
-                                                 height);
-                    }
+                    updatePanelSize();
+                    refreshScrollPosition();
 
                     final TransformMediator restriction = mousePanMediator.getTransformMediator();
                     final Transform transform = restriction.adjust(gridLayer.getViewport().getTransform(),
@@ -129,6 +127,18 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
 
     private final RestrictedMousePanMediator mousePanMediator = restrictedMousePanMediator();
 
+    @Inject
+    private ColumnManagementView actionsPanel;
+
+    @Inject
+    private ColumnManagementView conditionsPanel;
+
+    @Inject
+    private ManagedInstance<AttributeColumnConfigRow> attributeColumnConfigRows;
+
+    @Inject
+    private ManagedInstance<DeleteColumnManagementAnchorWidget> deleteColumnManagementAnchorWidgets;
+
     public GuidedDecisionTableModellerViewImpl() {
         initWidget(uiBinder.createAndBindUi(this));
     }
@@ -184,6 +194,8 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
     public void init(final GuidedDecisionTableModellerView.Presenter presenter) {
         this.presenter = presenter;
 
+        getActionsPanel().init(presenter);
+        getConditionsPanel().init(presenter);
         setupAccordion(presenter);
     }
 
@@ -195,7 +207,7 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
 
     void setupGridPanel() {
         //Lienzo stuff - Set default scale
-        final Transform transform = new Transform().scale(VP_SCALE);
+        final Transform transform = newTransform().scale(VP_SCALE);
         gridPanel.getViewport().setTransform(transform);
 
         //Lienzo stuff - Add mouse pan support
@@ -204,6 +216,10 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         gridPanel.getViewport().getMediators().push(mousePanMediator);
         mousePanMediator.setBatchDraw(true);
 
+        gridPanel.setBounds(getBounds());
+        gridPanel.getMainPanel().addDomHandler(scrollEvent -> getPresenter().updateRadar(),
+                                               ScrollEvent.getType());
+
         //Wire-up widgets
         gridPanel.add(gridLayer);
 
@@ -212,20 +228,22 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
     }
 
     void setupSubMenu() {
+        disableColumnOperationsMenu();
         getAddColumn().addClickHandler((e) -> addColumn());
         getEditColumns().addClickHandler((e) -> editColumns());
     }
 
     void addColumn() {
-        getPresenter().openNewGuidedDecisionTableColumnWizard();
+        if (getPresenter().isColumnCreationEnabledToActiveDecisionTable()) {
+            getPresenter().openNewGuidedDecisionTableColumnWizard();
+        }
     }
 
     void editColumns() {
-        toggleClassName(getAccordionContainer(),
-                        GuidedDecisionTableResources.INSTANCE.css().openedAccordion());
-
-        toggleClassName(getEditColumns(),
-                        "active");
+        if (getPresenter().isColumnCreationEnabledToActiveDecisionTable()) {
+            toggleClassName(getAccordionContainer(), GuidedDecisionTableResources.INSTANCE.css().openedAccordion());
+            toggleClassName(getEditColumns(), "active");
+        }
     }
 
     void toggleClassName(final Widget widget,
@@ -244,6 +262,18 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         return gridPanel.addKeyDownHandler(handler);
     }
 
+    @Override
+    public void enableColumnOperationsMenu() {
+        getAddColumn().setEnabled(true);
+        getEditColumns().setEnabled(true);
+    }
+
+    @Override
+    public void disableColumnOperationsMenu() {
+        getAddColumn().setEnabled(false);
+        getEditColumns().setEnabled(false);
+    }
+
     @Override
     public HandlerRegistration addContextMenuHandler(final ContextMenuHandler handler) {
         return gridPanel.addDomHandler(handler,
@@ -252,7 +282,12 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
 
     @Override
     public HandlerRegistration addMouseDownHandler(final MouseDownHandler handler) {
-        return gridPanel.addMouseDownHandler(handler);
+        return rootPanel().addDomHandler(handler,
+                                         MouseDownEvent.getType());
+    }
+
+    RootPanel rootPanel() {
+        return RootPanel.get();
     }
 
     Widget ruleInheritanceWidget() {
@@ -326,8 +361,11 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         }
         final Command remove = () -> {
             gridLayer.remove(gridWidget);
-            gridLayer.batch();
+
             afterRemovalCommand.execute();
+            disableColumnOperationsMenu();
+
+            gridLayer.batch();
         };
         if (gridLayer.isGridPinned()) {
             final GridPinnedModeManager.PinnedContext context = gridLayer.getPinnedContext();
@@ -351,6 +389,11 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         ruleSelector.setRuleNames(availableParentRuleNames);
     }
 
+    @Override
+    public void refreshScrollPosition() {
+        gridPanel.refreshScrollPosition();
+    }
+
     private VerticalPanel makeDefaultPanel() {
         return new VerticalPanel() {{
             add(blankSlate());
@@ -378,7 +421,7 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         }
 
         for (AttributeCol52 attributeColumn : attributeColumns) {
-            AttributeColumnConfigRow attributeColumnConfigRow = new AttributeColumnConfigRow();
+            AttributeColumnConfigRow attributeColumnConfigRow = getAttributeColumnConfigRows().get();
             attributeColumnConfigRow.init(attributeColumn,
                                           getPresenter());
             getAttributeConfigWidget().add(attributeColumnConfigRow.getView());
@@ -400,7 +443,7 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
             HorizontalPanel hp = new HorizontalPanel();
             hp.setVerticalAlignment(HasVerticalAlignment.ALIGN_MIDDLE);
 
-            final SmallLabel label = makeColumnLabel(metaDataColumn);
+            final ColumnLabelWidget label = makeColumnLabel(metaDataColumn);
             hp.add(label);
 
             final MetadataCol52 originalColumn = metaDataColumn;
@@ -420,20 +463,18 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
             hp.add(chkHideColumn);
 
             if (isEditable) {
-                hp.add(deleteAnchor((e) -> {
-                    String ms = GuidedDecisionTableConstants.INSTANCE.DeleteActionColumnWarning(metaDataColumn.getMetadata());
-                    if (Window.confirm(ms)) {
-                        presenter.getActiveDecisionTable().deleteColumn(metaDataColumn);
-                    }
-                }));
+                final DeleteColumnManagementAnchorWidget deleteWidget = deleteColumnManagementAnchorWidgets.get();
+                deleteWidget.init(metaDataColumn.getMetadata(),
+                                  () -> presenter.getActiveDecisionTable().deleteColumn(metaDataColumn));
+                hp.add(deleteWidget);
             }
 
             metaDataConfigWidget.add(hp);
         }
     }
 
-    private SmallLabel makeColumnLabel(final MetadataCol52 metaDataColumn) {
-        SmallLabel label = new SmallLabel(metaDataColumn.getMetadata());
+    private ColumnLabelWidget makeColumnLabel(final MetadataCol52 metaDataColumn) {
+        final ColumnLabelWidget label = new ColumnLabelWidget(metaDataColumn.getMetadata());
         ColumnUtilities.setColumnLabelStyleWhenHidden(label,
                                                       metaDataColumn.isHideColumn());
         return label;
@@ -441,131 +482,24 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
 
     @Override
     public void refreshConditionsWidget(final List<CompositeColumn<? extends BaseColumn>> conditionColumns) {
-        conditionsConfigWidget.clear();
+        getConditionsConfigWidget().clear();
 
         if (conditionColumns == null || conditionColumns.isEmpty()) {
-            accordion.getItem(GuidedDecisionTableAccordionItem.Type.CONDITION).setOpen(false);
-            conditionsConfigWidget.add(blankSlate());
+            getAccordion().getItem(GuidedDecisionTableAccordionItem.Type.CONDITION).setOpen(false);
+            getConditionsConfigWidget().add(blankSlate());
             return;
         }
 
-        //Each Pattern is a row in a vertical panel
-        final VerticalPanel patternsPanel = new VerticalPanel();
-        conditionsConfigWidget.add(patternsPanel);
+        getConditionsConfigWidget().add(getConditionsPanel());
 
-        final boolean isEditable = presenter.isActiveDecisionTableEditable();
-        for (CompositeColumn<?> conditionColumn : conditionColumns) {
-            if (conditionColumn instanceof Pattern52) {
-                Pattern52 p = (Pattern52) conditionColumn;
-                VerticalPanel patternPanel = new VerticalPanel();
-                VerticalPanel conditionsPanel = new VerticalPanel();
-                HorizontalPanel patternHeaderPanel = new HorizontalPanel();
-                Label patternLabel = makePatternLabel(p);
-                patternHeaderPanel.add(patternLabel);
-                patternPanel.add(patternHeaderPanel);
-                patternPanel.add(conditionsPanel);
-                patternsPanel.add(patternPanel);
-
-                List<ConditionCol52> conditions = p.getChildColumns();
-                for (ConditionCol52 c : conditions) {
-                    HorizontalPanel hp = new HorizontalPanel();
-
-                    SmallLabel conditionLabel = makeColumnLabel(c);
-                    hp.add(conditionLabel);
-
-                    final FlowPanel buttons = new FlowPanel() {{
-                        add(editCondition(p,
-                                          c));
-
-                        if (isEditable) {
-                            add(removeCondition(c));
-                        }
-                    }};
-
-                    hp.add(buttons);
-
-                    conditionsPanel.add(hp);
-                }
-            } else if (conditionColumn instanceof BRLConditionColumn) {
-                BRLConditionColumn brl = (BRLConditionColumn) conditionColumn;
-
-                HorizontalPanel patternHeaderPanel = new HorizontalPanel();
-                HorizontalPanel patternPanel = new HorizontalPanel();
-
-                SmallLabel patternLabel = makePatternLabel(brl);
-                patternPanel.add(patternLabel);
-                patternHeaderPanel.add(patternPanel);
-
-                final FlowPanel buttons = new FlowPanel() {{
-                    add(editCondition(brl));
-
-                    if (isEditable) {
-                        add(removeCondition(brl));
-                    }
-                }};
-
-                patternPanel.add(buttons);
-
-                patternsPanel.add(patternHeaderPanel);
-            }
-        }
-    }
-
-    private Label makePatternLabel(final Pattern52 p) {
-        StringBuilder patternLabel = new StringBuilder();
-        String factType = p.getFactType();
-        String boundName = p.getBoundName();
-        if (factType != null && factType.length() > 0) {
-            if (p.isNegated()) {
-                patternLabel.append(GuidedDecisionTableConstants.INSTANCE.negatedPattern()).append(" ").append(factType);
-            } else {
-                patternLabel.append(factType).append(" [").append(boundName).append("]");
-            }
-        }
-        return new Label(patternLabel.toString());
-    }
-
-    private SmallLabel makePatternLabel(final BRLConditionColumn brl) {
-        StringBuilder sb = new StringBuilder();
-        sb.append(brl.getHeader());
-        return new SmallLabel(sb.toString());
-    }
-
-    private SmallLabel makeColumnLabel(final ConditionCol52 cc) {
-        StringBuilder sb = new StringBuilder();
-        if (cc.isBound()) {
-            sb.append(cc.getBinding());
-            sb.append(" : ");
-        }
-        sb.append(cc.getHeader());
-        SmallLabel label = new SmallLabel(sb.toString());
-        if (cc.isHideColumn()) {
-            label.setStylePrimaryName(GuidedDecisionTableResources.INSTANCE.css().columnLabelHidden());
-        }
-        return label;
-    }
-
-    private Widget editCondition(final Pattern52 origPattern,
-                                 final ConditionCol52 origCol) {
-        return makeEditColumnWidget(GuidedDecisionTableConstants.INSTANCE.EditThisColumnsConfiguration(),
-                                    () -> presenter.getActiveDecisionTable().editCondition(origPattern,
-                                                                                           origCol));
-    }
-
-    private Widget editCondition(final BRLConditionColumn origCol) {
-        return makeEditColumnWidget(GuidedDecisionTableConstants.INSTANCE.EditThisColumnsConfiguration(),
-                                    () -> presenter.getActiveDecisionTable().editCondition(origCol));
-    }
-
-    private Widget makeEditColumnWidget(final String caption,
-                                        final Command command) {
-
-        return editAnchor((e) -> command.execute());
-    }
-
-    private Widget editAnchor(final ClickHandler clickHandler) {
-        return anchor(GuidedDecisionTableConstants.INSTANCE.Edit(),
-                      clickHandler);
+        final Map<String, List<BaseColumn>> columnGroups =
+                conditionColumns.stream().collect(
+                        Collectors.groupingBy(
+                                DecisionTableColumnViewUtils::getColumnManagementGroupTitle,
+                                Collectors.toList()
+                        )
+                );
+        getConditionsPanel().renderColumns(columnGroups);
     }
 
     private Widget deleteAnchor(final ClickHandler clickHandler) {
@@ -581,94 +515,28 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         }};
     }
 
-    private Widget removeCondition(final ConditionCol52 column) {
-        if (column instanceof BRLConditionColumn) {
-            return makeRemoveConditionWidget(column,
-                                             (command) -> {
-                                                 if (!presenter.getActiveDecisionTable().canConditionBeDeleted((BRLConditionColumn) column)) {
-                                                     Window.alert(GuidedDecisionTableConstants.INSTANCE.UnableToDeleteConditionColumn0(column.getHeader()));
-                                                     return;
-                                                 }
-                                                 command.execute();
-                                             });
-        }
-
-        return makeRemoveConditionWidget(column,
-                                         (command) -> {
-                                             if (!presenter.getActiveDecisionTable().canConditionBeDeleted(column)) {
-                                                 Window.alert(GuidedDecisionTableConstants.INSTANCE.UnableToDeleteConditionColumn0(column.getHeader()));
-                                                 return;
-                                             }
-                                             command.execute();
-                                         });
-    }
-
-    private Widget makeRemoveConditionWidget(final ConditionCol52 column,
-                                             final ParameterizedCommand<Command> command) {
-
-        final ClickHandler clickHandler = (e) -> command.execute(() -> {
-            String cm = GuidedDecisionTableConstants.INSTANCE.DeleteConditionColumnWarning0(column.getHeader());
-            if (Window.confirm(cm)) {
-                presenter.getActiveDecisionTable().deleteColumn(column);
-            }
-        });
-
-        return deleteAnchor(clickHandler);
-    }
-
     @Override
     public void refreshActionsWidget(final List<ActionCol52> actionColumns) {
-        actionsConfigWidget.clear();
+        getActionsConfigWidget().clear();
 
         if (actionColumns == null || actionColumns.isEmpty()) {
-            accordion.getItem(GuidedDecisionTableAccordionItem.Type.ACTION).setOpen(false);
-            actionsConfigWidget.add(blankSlate());
+            getAccordion().getItem(GuidedDecisionTableAccordionItem.Type.ACTION).setOpen(false);
+            getActionsConfigWidget().add(blankSlate());
             return;
         }
 
         //Each Action is a row in a vertical panel
-        final VerticalPanel actionsPanel = new VerticalPanel();
-        this.actionsConfigWidget.add(actionsPanel);
+        getActionsConfigWidget().add(getActionsPanel());
 
         //Add Actions to panel
-        final boolean isEditable = presenter.isActiveDecisionTableEditable();
-        for (ActionCol52 actionColumn : actionColumns) {
-            HorizontalPanel hp = new HorizontalPanel();
-
-            Label actionLabel = makeColumnLabel(actionColumn);
-            hp.add(actionLabel);
-
-            final FlowPanel buttons = new FlowPanel() {{
-                add(editAction(actionColumn));
-
-                if (isEditable) {
-                    add(deleteAnchor((e) -> {
-                        final String cm = GuidedDecisionTableConstants.INSTANCE.DeleteActionColumnWarning(actionColumn.getHeader());
-
-                        if (Window.confirm(cm)) {
-                            presenter.getActiveDecisionTable().deleteColumn(actionColumn);
-                        }
-                    }));
-                }
-            }};
-
-            hp.add(buttons);
-
-            actionsPanel.add(hp);
-        }
-    }
-
-    private SmallLabel makeColumnLabel(final ActionCol52 actionColumn) {
-        SmallLabel label = new SmallLabel(actionColumn.getHeader());
-        if (actionColumn.isHideColumn()) {
-            label.setStylePrimaryName(GuidedDecisionTableResources.INSTANCE.css().columnLabelHidden());
-        }
-        return label;
-    }
-
-    private Widget editAction(final ActionCol52 actionColumn) {
-        return makeEditColumnWidget(GuidedDecisionTableConstants.INSTANCE.EditThisActionColumnConfiguration(),
-                                    () -> presenter.getActiveDecisionTable().editAction(actionColumn));
+        final Map<String, List<BaseColumn>> columnGroups =
+                actionColumns.stream().collect(
+                        Collectors.groupingBy(
+                                DecisionTableColumnViewUtils::getColumnManagementGroupTitle,
+                                Collectors.toList()
+                        )
+                );
+        getActionsPanel().renderColumns(columnGroups);
     }
 
     @Override
@@ -679,7 +547,7 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
     @Override
     public void setZoom(final int zoom) {
         //Set zoom preserving translation
-        final Transform transform = new Transform();
+        final Transform transform = newTransform();
         final double tx = gridPanel.getViewport().getTransform().getTranslateX();
         final double ty = gridPanel.getViewport().getTransform().getTranslateY();
         transform.translate(tx,
@@ -694,6 +562,7 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
                                                           gridLayer.getVisibleBounds());
         gridPanel.getViewport().setTransform(newTransform);
         gridPanel.getViewport().batch();
+        gridPanel.refreshScrollPosition();
     }
 
     @Override
@@ -722,8 +591,8 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
 
     @Override
     public void select(final GridWidget selectedGridWidget) {
-        ruleSelector.setEnabled(true);
-        gridLayer.select(selectedGridWidget);
+        getRuleSelector().setEnabled(true);
+        getGridLayer().select(selectedGridWidget);
     }
 
     @Override
@@ -810,6 +679,26 @@ public class GuidedDecisionTableModellerViewImpl extends Composite implements Gu
         return accordion;
     }
 
+    DefaultGridLayer getGridLayer() {
+        return gridLayer;
+    }
+
+    Transform newTransform() {
+        return new Transform();
+    }
+
+    ColumnManagementView getActionsPanel() {
+        return actionsPanel;
+    }
+
+    ColumnManagementView getConditionsPanel() {
+        return conditionsPanel;
+    }
+
+    ManagedInstance<AttributeColumnConfigRow> getAttributeColumnConfigRows() {
+        return attributeColumnConfigRows;
+    }
+
     interface GuidedDecisionTableModellerViewImplUiBinder extends UiBinder<Widget, GuidedDecisionTableModellerViewImpl> {
 
     }
