@@ -100,6 +100,7 @@ import org.kie.workbench.common.services.shared.rulename.RuleNamesService;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
+import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.client.mvp.LockTarget;
@@ -114,6 +115,8 @@ import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.impl.RowS
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.TransformMediator;
 import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.rpc.SessionInfo;
+import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter.Access.LockedBy.CURRENT_USER;
@@ -148,6 +151,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     private final Access access = new Access();
     private final PluginHandler pluginHandler;
+    private final AuthorizationManager authorizationManager;
+    private final SessionInfo sessionInfo;
 
     protected CellUtilities cellUtilities;
     protected ColumnUtilities columnUtilities;
@@ -196,7 +201,10 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                                         final Clipboard clipboard,
                                         final DecisionTableAnalyzerProvider decisionTableAnalyzerProvider,
                                         final EnumLoaderUtilities enumLoaderUtilities,
-                                        final PluginHandler pluginHandler) {
+                                        final PluginHandler pluginHandler,
+                                        final AuthorizationManager authorizationManager,
+                                        final SessionInfo sessionInfo) {
+
         this.identity = identity;
         this.resourceType = resourceType;
         this.ruleNameService = ruleNameService;
@@ -219,6 +227,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         this.decisionTableAnalyzerProvider = decisionTableAnalyzerProvider;
         this.enumLoaderUtilities = enumLoaderUtilities;
         this.pluginHandler = pluginHandler;
+        this.authorizationManager = authorizationManager;
+        this.sessionInfo = sessionInfo;
 
         CellUtilities.injectDateConvertor(getDateConverter());
 
@@ -320,13 +330,13 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         this.oracle = oracleFactory.makeAsyncPackageDataModelOracle(path,
                                                                     model,
                                                                     dataModel);
-        this.access.setReadOnly(isReadOnly);
         this.rm = new BRLRuleModel(model);
 
         this.uiModel = makeUiModel();
         this.renderer = makeViewRenderer();
         this.view = makeView(workItemDefinitions);
 
+        initialiseAccess(isReadOnly);
         initialiseLockManager();
         initialiseUtilities();
         initialiseModels();
@@ -335,19 +345,33 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         initialiseAuditLog();
     }
 
+    void initialiseAccess(final boolean isReadOnly) {
+        getAccess().setReadOnly(isReadOnly);
+        getAccess().setHasEditableColumns(canEditColumns());
+    }
+
+    boolean canEditColumns() {
+
+        final String permission = WorkbenchFeatures.GUIDED_DECISION_TABLE_EDIT_COLUMNS;
+        final User user = sessionInfo.getIdentity();
+
+        return authorizationManager.authorize(permission, user);
+    }
+
     //Setup LockManager
     void initialiseLockManager() {
         lockManager.init(new LockTarget(currentPath,
                                         parent.getView().asWidget(),
                                         placeRequest,
                                         () -> currentPath.getFileName() + " - " + resourceType.getDescription(),
-                                        () -> {/*nothing*/}),
+                                        () -> {/*Nothing*/}),
                          parent);
     }
 
     //Instantiate UiModel overriding cell selection to inform MenuItems about changes to selected cells.
     GuidedDecisionTableUiModel makeUiModel() {
         return new GuidedDecisionTableUiModel(synchronizer) {
+
             @Override
             public Range selectCell(final int rowIndex,
                                     final int columnIndex) {
@@ -379,6 +403,28 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             public boolean isColumnDraggingEnabled() {
                 return access.isEditable();
             }
+
+            @Override
+            public Range deleteCell(int rowIndex,
+                                    int columnIndex) {
+                Range cellRange = super.deleteCell(rowIndex,
+                                                   columnIndex);
+                decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
+                return cellRange;
+            }
+
+            @Override
+            public void deleteColumn(GridColumn<?> column) {
+                super.deleteColumn(column);
+                decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
+            }
+
+            @Override
+            public Range deleteRow(int rowIndex) {
+                Range rowRange = super.deleteRow(rowIndex);
+                decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
+                return rowRange;
+            }
         };
     }
 
@@ -392,8 +438,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                                                renderer,
                                                this,
                                                model,
-                                               notificationEvent
-        );
+                                               notificationEvent);
     }
 
     void initialiseUtilities() {
@@ -468,10 +513,12 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         view.registerNodeMouseDoubleClickHandler((event) -> {
             if (view.isNodeMouseEventOverCaption(event)) {
                 if (isGridPinned()) {
-                    exitPinnedMode(() -> {/*Nothing*/});
+                    exitPinnedMode(() -> {
+                        /*Nothing*/});
                 } else {
                     enterPinnedMode(view,
-                                    () -> {/*Nothing*/});
+                                    () -> {
+                                        /*Nothing*/});
                 }
             }
         });
@@ -505,6 +552,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         }
         Collections.sort(converters,
                          new Comparator<BaseColumnConverter>() {
+
                              @Override
                              public int compare(final BaseColumnConverter o1,
                                                 final BaseColumnConverter o2) {
@@ -641,9 +689,24 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         return parent.getDefaultTransformMediator();
     }
 
+    @Override
+    public void addOnEnterPinnedModeCommand(final Command command) {
+        getParent().addOnEnterPinnedModeCommand(command);
+    }
+
+    @Override
+    public void addOnExitPinnedModeCommand(final Command command) {
+        getParent().addOnExitPinnedModeCommand(command);
+    }
+
+    GuidedDecisionTableModellerView.Presenter getParent() {
+        return parent;
+    }
+
     @Override
     public void getPackageParentRuleNames(final ParameterizedCommand<Collection<String>> command) {
         ruleNameService.call(new RemoteCallback<Collection<String>>() {
+
             @Override
             public void callback(final Collection<String> ruleNames) {
                 command.execute(ruleNames);
@@ -659,9 +722,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public boolean hasColumnDefinitions() {
-        return model.getAttributeCols().size() > 0
-                || model.getConditionsCount() > 0
-                || model.getActionCols().size() > 0;
+        return model.getAttributeCols().size() > 0 || model.getConditionsCount() > 0 || model.getActionCols().size() > 0;
     }
 
     @Override
@@ -847,9 +908,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         try {
             append.execute();
 
-            parent.updateLinks();
-
-            view.getLayer().draw();
+            refreshView();
 
             //Log addition of column
             model.getAuditLog().add(new InsertColumnAuditLogEntry(identity.getIdentifier(),
@@ -868,9 +927,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         try {
             synchronizer.appendRow();
 
-            parent.updateLinks();
-
-            view.getLayer().draw();
+            refreshView();
 
             //Log insertion of row
             model.getAuditLog().add(new InsertRowAuditLogEntry(identity.getIdentifier(),
@@ -880,6 +937,13 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         }
     }
 
+    void refreshView() {
+        getParent().updateLinks();
+        getParent().refreshScrollPosition();
+
+        view.getLayer().draw();
+    }
+
     @Override
     public void deleteColumn(final AttributeCol52 column) {
         doDeleteColumn(column,
@@ -916,9 +980,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         try {
             synchronizer.deleteColumn(column);
 
-            parent.updateLinks();
-
-            view.getLayer().draw();
+            refreshView();
 
             //Log deletion of column
             model.getAuditLog().add(new DeleteColumnAuditLogEntry(identity.getIdentifier(),
@@ -1252,9 +1314,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         try {
             synchronizer.deleteRow(rowIndex);
 
-            parent.updateLinks();
-
-            view.getLayer().draw();
+            refreshView();
 
             //Log deletion of column
             model.getAuditLog().add(new DeleteRowAuditLogEntry(identity.getIdentifier(),
@@ -1313,9 +1373,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         try {
             synchronizer.insertRow(rowIndex);
 
-            parent.updateLinks();
-
-            view.getLayer().draw();
+            refreshView();
 
             //Log insertion of row
             model.getAuditLog().add(new InsertRowAuditLogEntry(identity.getIdentifier(),
@@ -1381,6 +1439,11 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         return !this.access.isEditable();
     }
 
+    @Override
+    public boolean hasEditableColumns() {
+        return getAccess().hasEditableColumns();
+    }
+
     @Override
     public void setReadOnly(final boolean isReadOnly) {
         this.access.setReadOnly(isReadOnly);
@@ -1420,6 +1483,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
         private LockedBy lock = NOBODY;
         private boolean isReadOnly = false;
+        private boolean hasEditableColumns = false;
 
         public LockedBy getLock() {
             return lock;
@@ -1433,6 +1497,14 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             return isReadOnly;
         }
 
+        public boolean hasEditableColumns() {
+            return hasEditableColumns;
+        }
+
+        public void setHasEditableColumns(final boolean hasEditableColumns) {
+            this.hasEditableColumns = hasEditableColumns;
+        }
+
         public void setReadOnly(final boolean isReadOnly) {
             this.isReadOnly = isReadOnly;
         }
