@@ -16,14 +16,19 @@
 
 package org.drools.workbench.screens.guided.dtable.client.wizard.column.commons;
 
+import java.util.Collection;
+
 import org.drools.workbench.models.datamodel.rule.RuleModel;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.rule.client.editor.RuleModellerConfiguration;
+import org.drools.workbench.screens.guided.rule.client.editor.plugin.RuleModellerActionPlugin;
 
 public interface HasRuleModellerPage {
 
     RuleModel getRuleModel();
 
+    Collection<RuleModellerActionPlugin> getRuleModellerActionPlugins();
+
     RuleModellerConfiguration getRuleModellerConfiguration();
 
     String getRuleModellerDescription();
