@@ -130,6 +130,16 @@ public class ActionRetractFactPlugin extends BaseDecisionTableColumnPlugin imple
                 .collect(Collectors.toSet());
     }
 
+    @Override
+    public boolean isHideColumn() {
+        return editingCol().isHideColumn();
+    }
+
+    @Override
+    public void setHideColumn(boolean hideColumn) {
+        editingCol().setHideColumn(hideColumn);
+    }
+
     @Override
     public void setInsertLogical(final Boolean value) {
         // empty
