@@ -203,6 +203,16 @@ public class ActionWorkItemPlugin extends BaseDecisionTableColumnPlugin implemen
         // empty
     }
 
+    @Override
+    public boolean isHideColumn() {
+        return editingCol().isHideColumn();
+    }
+
+    @Override
+    public void setHideColumn(boolean hideColumn) {
+        editingCol().setHideColumn(hideColumn);
+    }
+
     @Override
     public void setInsertLogical(final Boolean value) {
         // empty
