@@ -18,6 +18,7 @@ package org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -26,6 +27,7 @@ import java.util.Set;
 import java.util.stream.Collectors;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
+import javax.enterprise.inject.Instance;
 import javax.inject.Inject;
 
 import com.google.gwt.event.shared.HandlerRegistration;
@@ -50,6 +52,7 @@ import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.c
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.commons.BaseDecisionTableColumnPlugin;
 import org.drools.workbench.screens.guided.rule.client.editor.RuleModellerConfiguration;
 import org.drools.workbench.screens.guided.rule.client.editor.events.TemplateVariablesChangedEvent;
+import org.drools.workbench.screens.guided.rule.client.editor.plugin.RuleModellerActionPlugin;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPage;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
@@ -61,6 +64,8 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
 
     private RuleModellerPage ruleModellerPage;
 
+    private Collection<RuleModellerActionPlugin> actionPlugins = new ArrayList<>();
+
     private AdditionalInfoPage<BRLActionColumnPlugin> additionalInfoPage;
 
     private BRLActionColumn editingCol;
@@ -73,6 +78,7 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
 
     @Inject
     public BRLActionColumnPlugin(final RuleModellerPage ruleModellerPage,
+                                 final Instance<RuleModellerActionPlugin> actionPluginInstance,
                                  final AdditionalInfoPage<BRLActionColumnPlugin> additionalInfoPage,
                                  final Event<WizardPageStatusChangeEvent> changeEvent,
                                  final TranslationService translationService) {
@@ -80,6 +86,7 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
               translationService);
 
         this.ruleModellerPage = ruleModellerPage;
+        actionPluginInstance.iterator().forEachRemaining(actionPlugins::add);
         this.additionalInfoPage = additionalInfoPage;
     }
 
@@ -205,12 +212,12 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
 
     @Override
     public String getHeader() {
-        return editingCol.getHeader();
+        return editingCol().getHeader();
     }
 
     @Override
     public void setHeader(final String header) {
-        editingCol.setHeader(header);
+        editingCol().setHeader(header);
 
         fireChangeEvent(additionalInfoPage);
     }
@@ -225,6 +232,16 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
                 .collect(Collectors.toSet());
     }
 
+    @Override
+    public boolean isHideColumn() {
+        return editingCol().isHideColumn();
+    }
+
+    @Override
+    public void setHideColumn(boolean hideColumn) {
+        editingCol().setHideColumn(hideColumn);
+    }
+
     @Override
     public void setInsertLogical(final Boolean value) {
         // empty
@@ -262,6 +279,11 @@ public class BRLActionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
         return ruleModel;
     }
 
+    @Override
+    public Collection<RuleModellerActionPlugin> getRuleModellerActionPlugins() {
+        return actionPlugins;
+    }
+
     private RuleModel newRuleModel() {
         final BRLRuleModel ruleModel = new BRLRuleModel(presenter.getModel());
         final List<IAction> definition = editingCol.getDefinition();
