@@ -18,6 +18,7 @@ package org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -57,11 +58,12 @@ import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.c
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.commons.BaseDecisionTableColumnPlugin;
 import org.drools.workbench.screens.guided.rule.client.editor.RuleModellerConfiguration;
 import org.drools.workbench.screens.guided.rule.client.editor.events.TemplateVariablesChangedEvent;
+import org.drools.workbench.screens.guided.rule.client.editor.plugin.RuleModellerActionPlugin;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPage;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
 
-import static org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52.TableFormat.*;
+import static org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52.TableFormat.LIMITED_ENTRY;
 
 @Dependent
 public class BRLConditionColumnPlugin extends BaseDecisionTableColumnPlugin implements HasRuleModellerPage,
@@ -198,12 +200,12 @@ public class BRLConditionColumnPlugin extends BaseDecisionTableColumnPlugin impl
 
     @Override
     public String getHeader() {
-        return editingCol.getHeader();
+        return editingCol().getHeader();
     }
 
     @Override
     public void setHeader(String header) {
-        editingCol.setHeader(header);
+        editingCol().setHeader(header);
 
         fireChangeEvent(additionalInfoPage);
     }
@@ -230,6 +232,16 @@ public class BRLConditionColumnPlugin extends BaseDecisionTableColumnPlugin impl
         return getPresenter().getModel();
     }
 
+    @Override
+    public boolean isHideColumn() {
+        return editingCol().isHideColumn();
+    }
+
+    @Override
+    public void setHideColumn(boolean hideColumn) {
+        editingCol().setHideColumn(hideColumn);
+    }
+
     @Override
     public void setInsertLogical(Boolean value) {
         // empty
@@ -267,6 +279,11 @@ public class BRLConditionColumnPlugin extends BaseDecisionTableColumnPlugin impl
         return ruleModel;
     }
 
+    @Override
+    public Collection<RuleModellerActionPlugin> getRuleModellerActionPlugins() {
+        return Collections.emptyList();
+    }
+
     private RuleModel newRuleModel() {
         final BRLRuleModel ruleModel = new BRLRuleModel(getModel());
         final List<IPattern> definition = editingCol.getDefinition();
