@@ -48,7 +48,7 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.model.conv
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionInsertFactColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionRetractFactColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionSetFieldColumnConverter;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionWorkItemColumnConverter;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionWorkItemExecuteColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionWorkItemInsertFactColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.ActionWorkItemSetFieldColumnConverter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.AttributeColumnConverter;
@@ -66,7 +66,7 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.model.sync
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionInsertFactColumnSynchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionRetractFactColumnSynchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionSetFieldColumnSynchronizer;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionWorkItemColumnSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionWorkItemExecuteColumnSynchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionWorkItemInsertFactColumnSynchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.ActionWorkItemSetFieldColumnSynchronizer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.AttributeColumnSynchronizer;
@@ -102,6 +102,8 @@ import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.DefaultGridLay
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.rpc.SessionInfo;
+import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.mockito.Mockito.*;
@@ -147,6 +149,12 @@ public abstract class BaseGuidedDecisionTablePresenterTest {
     @Mock
     protected GuidedDecisionTableLockManager lockManager;
 
+    @Mock
+    protected AuthorizationManager authorizationManager;
+
+    @Mock
+    protected SessionInfo sessionInfo;
+
     protected GuidedDecisionTableLinkManager linkManager;
 
     protected Event<DecisionTableSelectedEvent> decisionTableSelectedEvent = spy(new EventSourceMock<DecisionTableSelectedEvent>() {
@@ -310,7 +318,9 @@ public abstract class BaseGuidedDecisionTablePresenterTest {
                                                                                       clipboard,
                                                                                       decisionTableAnalyzerProvider,
                                                                                       enumLoaderUtilities,
-                                                                                      pluginHandler) {
+                                                                                      pluginHandler,
+                                                                                      authorizationManager,
+                                                                                      sessionInfo) {
             @Override
             void initialiseLockManager() {
                 //Do nothing for tests
@@ -337,7 +347,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest {
                 converters.add(new ActionInsertFactColumnConverter());
                 converters.add(new ActionRetractFactColumnConverter());
                 converters.add(new ActionSetFieldColumnConverter());
-                converters.add(new ActionWorkItemColumnConverter());
+                converters.add(new ActionWorkItemExecuteColumnConverter());
                 converters.add(new ActionWorkItemInsertFactColumnConverter());
                 converters.add(new ActionWorkItemSetFieldColumnConverter());
                 converters.add(new AttributeColumnConverter());
@@ -358,7 +368,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest {
                 synchronizers.add(new ActionInsertFactColumnSynchronizer());
                 synchronizers.add(new ActionRetractFactColumnSynchronizer());
                 synchronizers.add(new ActionSetFieldColumnSynchronizer());
-                synchronizers.add(new ActionWorkItemColumnSynchronizer());
+                synchronizers.add(new ActionWorkItemExecuteColumnSynchronizer());
                 synchronizers.add(new ActionWorkItemInsertFactColumnSynchronizer());
                 synchronizers.add(new ActionWorkItemSetFieldColumnSynchronizer());
                 synchronizers.add(new AttributeColumnSynchronizer());
