@@ -39,7 +39,6 @@ import org.drools.workbench.models.guided.dtable.shared.model.CompositeColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.accordion.GuidedDecisionTableAccordion;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTablePinnedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
@@ -52,7 +51,6 @@ import org.drools.workbench.screens.guided.dtable.client.wizard.column.NewGuided
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
-import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -62,7 +60,11 @@ import org.mockito.Mock;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.ext.wires.core.grids.client.model.Bounds;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseBounds;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.columns.GridColumnRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridLayer;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.ParameterizedCommand;
@@ -108,6 +110,9 @@ public class GuidedDecisionTableModellerPresenterTest {
     @Mock
     private GuidedDecisionTableView.Presenter dtablePresenter;
 
+    @Mock
+    private GuidedDecisionTable52 model;
+
     @Mock
     private GuidedDecisionTableView dtableView;
 
@@ -140,15 +145,18 @@ public class GuidedDecisionTableModellerPresenterTest {
 
         when(dtablePresenterProvider.get()).thenReturn(dtablePresenter);
         when(dtablePresenter.getView()).thenReturn(dtableView);
+        when(dtableView.getModel()).thenReturn(new BaseGridData());
     }
 
     private GuidedDecisionTableView.Presenter makeDecisionTable() {
         final GuidedDecisionTableView.Presenter dtPresenter = mock(GuidedDecisionTableView.Presenter.class);
         final GuidedDecisionTableView dtView = mock(GuidedDecisionTableView.class);
+        final GridData dtData = new BaseGridData();
 
         when(dtPresenter.getView()).thenReturn(dtView);
         when(dtPresenter.getAccess()).thenReturn(mock(GuidedDecisionTablePresenter.Access.class));
         when(dtPresenter.getModel()).thenReturn(mock(GuidedDecisionTable52.class));
+        when(dtView.getModel()).thenReturn(dtData);
 
         return dtPresenter;
     }
@@ -166,6 +174,13 @@ public class GuidedDecisionTableModellerPresenterTest {
         return dtContent;
     }
 
+    @SuppressWarnings("unchecked")
+    private GridColumn makeUiColumn() {
+        return spy(new BaseGridColumn(mock(GridColumn.HeaderMetaData.class),
+                                      mock(GridColumnRenderer.class),
+                                      100.0));
+    }
+
     @Test
     public void onClose() {
         presenter.onClose();
@@ -289,6 +304,8 @@ public class GuidedDecisionTableModellerPresenterTest {
                times(1)).refreshColumnsNote(eq(false));
         verify(dtPresenter,
                times(1)).onClose();
+        verify(presenter,
+               times(1)).removeLinksForDecisionTable(eq(dtPresenter));
     }
 
     @Test
@@ -717,6 +734,32 @@ public class GuidedDecisionTableModellerPresenterTest {
         assertFalse(pinnedEvent.isPinned());
     }
 
+    @Test
+    public void testAddOnEnterPinnedModeCommand() {
+
+        final Command command = mock(Command.class);
+        final GridLayer gridLayer = mock(GridLayer.class);
+
+        doReturn(gridLayer).when(view).getGridLayerView();
+
+        presenter.addOnEnterPinnedModeCommand(command);
+
+        verify(gridLayer).addOnEnterPinnedModeCommand(command);
+    }
+
+    @Test
+    public void testAddOnExitPinnedModeCommand() {
+
+        final Command command = mock(Command.class);
+        final GridLayer gridLayer = mock(GridLayer.class);
+
+        doReturn(gridLayer).when(view).getGridLayerView();
+
+        presenter.addOnExitPinnedModeCommand(command);
+
+        verify(gridLayer).addOnExitPinnedModeCommand(command);
+    }
+
     @Test
     public void updateLinks() {
         final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
@@ -738,4 +781,158 @@ public class GuidedDecisionTableModellerPresenterTest {
         verify(gridLayer,
                times(1)).refreshGridWidgetConnectors();
     }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void checkRemoveLinksPreservesOtherTables() {
+        final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
+        final GuidedDecisionTableView.Presenter dtPresenter2 = makeDecisionTable();
+        final Set<GuidedDecisionTableView.Presenter> availableDecisionTables = new HashSet<GuidedDecisionTableView.Presenter>() {{
+            add(dtPresenter2);
+        }};
+
+        final GridColumn dtPresenter1Column1 = makeUiColumn();
+        final GridColumn dtPresenter1Column2 = makeUiColumn();
+        final GridColumn dtPresenter2Column1 = makeUiColumn();
+        final GridColumn dtPresenter2Column2 = makeUiColumn();
+        dtPresenter1.getView().getModel().appendColumn(dtPresenter1Column1);
+        dtPresenter1.getView().getModel().appendColumn(dtPresenter1Column2);
+        dtPresenter2.getView().getModel().appendColumn(dtPresenter2Column1);
+        dtPresenter2.getView().getModel().appendColumn(dtPresenter2Column2);
+
+        dtPresenter1Column2.setLink(dtPresenter2Column2);
+        dtPresenter2Column1.setLink(dtPresenter1Column1);
+
+        when(presenter.getAvailableDecisionTables()).thenReturn(availableDecisionTables);
+
+        //Check setup
+        verify(dtPresenter1Column2,
+               times(1)).setLink(eq(dtPresenter2Column2));
+        verify(dtPresenter2Column1,
+               times(1)).setLink(eq(dtPresenter1Column1));
+
+        reset(dtPresenter1Column1,
+              dtPresenter1Column2,
+              dtPresenter2Column1,
+              dtPresenter2Column2);
+
+        //Check links after removal
+        presenter.removeLinksForDecisionTable(dtPresenter1);
+
+        verify(dtPresenter1Column1,
+               never()).setLink(any());
+        verify(dtPresenter1Column2,
+               never()).setLink(any());
+
+        verify(dtPresenter2Column1,
+               times(1)).setLink(eq(null));
+        verify(dtPresenter2Column2,
+               never()).setLink(any());
+    }
+
+    @Test
+    public void testHandlePermissionsWhenGuidedDecisionTableHasEditableColumns() {
+
+        doReturn(true).when(dtablePresenter).hasEditableColumns();
+
+        presenter.handlePermissions(dtablePresenter);
+
+        verify(view).enableColumnOperationsMenu();
+    }
+
+    @Test
+    public void testHandlePermissionsWhenGuidedDecisionTableDoesNotHaveEditableColumns() {
+
+        doReturn(false).when(dtablePresenter).hasEditableColumns();
+
+        presenter.handlePermissions(dtablePresenter);
+
+        verify(view, never()).enableColumnOperationsMenu();
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsEditableAndHasEditableColumns() {
+
+        doReturn(model).when(dtablePresenter).getModel();
+        doReturn(false).when(dtablePresenter).isReadOnly();
+        doReturn(true).when(dtablePresenter).hasEditableColumns();
+
+        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
+
+        assertTrue(isEnabled);
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledWhenGuidedDecisionTableDoesNotHaveEditableColumns() {
+
+        doReturn(model).when(dtablePresenter).getModel();
+        doReturn(false).when(dtablePresenter).isReadOnly();
+        doReturn(false).when(dtablePresenter).hasEditableColumns();
+
+        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
+
+        assertFalse(isEnabled);
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsNotEditable() {
+
+        doReturn(model).when(dtablePresenter).getModel();
+        doReturn(true).when(dtablePresenter).isReadOnly();
+        doReturn(true).when(dtablePresenter).hasEditableColumns();
+
+        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
+
+        assertFalse(isEnabled);
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsNotEditableNeitherHasEditableColumns() {
+
+        doReturn(model).when(dtablePresenter).getModel();
+        doReturn(true).when(dtablePresenter).isReadOnly();
+        doReturn(false).when(dtablePresenter).hasEditableColumns();
+
+        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
+
+        assertFalse(isEnabled);
+    }
+
+    @Test
+    public void testRefreshDefinitionsPanel() {
+
+        doReturn(model).when(dtablePresenter).getModel();
+        doReturn(true).when(presenter).isColumnCreationEnabled(dtablePresenter);
+
+        presenter.refreshDefinitionsPanel(dtablePresenter);
+
+        verify(view).setEnableColumnCreation(true);
+        verify(view).refreshAttributeWidget(model.getAttributeCols());
+        verify(view).refreshMetaDataWidget(model.getMetadataCols());
+        verify(view).refreshConditionsWidget(model.getConditions());
+        verify(view).refreshActionsWidget(model.getActionCols());
+        verify(view).refreshColumnsNote(dtablePresenter.hasColumnDefinitions());
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledToActiveDecisionTableWhenActiveDecisionTableIsNull() {
+
+        doReturn(null).when(presenter).getActiveDecisionTable();
+        doReturn(true).when(presenter).isColumnCreationEnabled(any());
+
+        final boolean isEnabled = presenter.isColumnCreationEnabledToActiveDecisionTable();
+
+        assertFalse(isEnabled);
+    }
+
+    @Test
+    public void testIsColumnCreationEnabledToActiveDecisionTableWhenActiveDecisionTableIsNotNull() {
+
+        doReturn(dtablePresenter).when(presenter).getActiveDecisionTable();
+        doReturn(true).when(presenter).isColumnCreationEnabled(dtablePresenter);
+
+        final boolean isEnabled = presenter.isColumnCreationEnabledToActiveDecisionTable();
+
+        assertTrue(isEnabled);
+    }
 }
