@@ -17,6 +17,7 @@
 package org.drools.workbench.screens.guided.dtable.client.widget.table;
 
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -26,11 +27,15 @@ import com.ait.lienzo.client.core.event.NodeDragMoveEvent;
 import com.ait.lienzo.client.core.event.NodeDragMoveHandler;
 import com.ait.lienzo.client.core.event.NodeMouseDoubleClickEvent;
 import com.ait.lienzo.client.core.event.NodeMouseDoubleClickHandler;
+import com.ait.lienzo.client.core.shape.Layer;
 import com.google.gwt.user.client.Command;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.oracle.DropDownData;
+import org.drools.workbench.models.datamodel.rule.ActionFieldValue;
+import org.drools.workbench.models.datamodel.rule.ActionInsertFact;
 import org.drools.workbench.models.datamodel.rule.FactPattern;
+import org.drools.workbench.models.datamodel.rule.FieldNatureType;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BRLActionColumn;
@@ -43,6 +48,7 @@ import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.screens.guided.dtable.client.widget.analysis.panel.IssueSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectionsChangedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
@@ -52,10 +58,12 @@ import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableLin
 import org.drools.workbench.screens.guided.rule.client.editor.RuleAttributeWidget;
 import org.drools.workbench.services.verifier.api.client.reporting.Issue;
 import org.drools.workbench.services.verifier.api.client.reporting.Severity;
+import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
+import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -232,6 +240,8 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).makeUiModel();
         verify(dtPresenter,
                times(1)).makeView(any(Set.class));
+        verify(dtPresenter,
+               times(1)).initialiseAccess(false);
         verify(dtPresenter,
                times(1)).initialiseLockManager();
         verify(dtPresenter,
@@ -285,6 +295,8 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(2)).makeUiModel();
         verify(dtPresenter,
                times(2)).makeView(any(Set.class));
+        verify(dtPresenter,
+               times(2)).initialiseAccess(false);
         verify(dtPresenter,
                times(2)).initialiseLockManager();
         verify(dtPresenter,
@@ -406,11 +418,14 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     public void link() {
         final GuidedDecisionTableView.Presenter dtPresenter2 = mock(GuidedDecisionTableView.Presenter.class);
         final GuidedDecisionTableView.Presenter dtPresenter3 = mock(GuidedDecisionTableView.Presenter.class);
-        final Set<GuidedDecisionTableView.Presenter> dtPresenters = new HashSet<GuidedDecisionTableView.Presenter>() {{
-            add(dtPresenter);
-            add(dtPresenter2);
-            add(dtPresenter3);
-        }};
+        final Set<GuidedDecisionTableView.Presenter> dtPresenters = new HashSet<GuidedDecisionTableView.Presenter>() {
+
+            {
+                add(dtPresenter);
+                add(dtPresenter2);
+                add(dtPresenter3);
+            }
+        };
         when(dtPresenter.getModel()).thenReturn(model1);
         when(dtPresenter2.getModel()).thenReturn(model2);
         when(dtPresenter3.getModel()).thenReturn(model3);
@@ -619,11 +634,14 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         final GuidedDecisionTableView dtView3 = mock(GuidedDecisionTableView.class);
         final GuidedDecisionTableView.Presenter dtPresenter2 = setupPresenter();
         final GuidedDecisionTableView.Presenter dtPresenter3 = setupPresenter();
-        final Set<GuidedDecisionTableView.Presenter> dtPresenters = new HashSet<GuidedDecisionTableView.Presenter>() {{
-            add(dtPresenter);
-            add(dtPresenter2);
-            add(dtPresenter3);
-        }};
+        final Set<GuidedDecisionTableView.Presenter> dtPresenters = new HashSet<GuidedDecisionTableView.Presenter>() {
+
+            {
+                add(dtPresenter);
+                add(dtPresenter2);
+                add(dtPresenter3);
+            }
+        };
 
         when(dtPresenter.getModel()).thenReturn(model1);
         when(dtPresenter2.getModel()).thenReturn(model2);
@@ -672,8 +690,16 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                                            final String factType,
                                            final String field) {
         final BRLActionColumn brlAction = new BRLActionColumn();
-        BRLActionVariableColumn variableColumn = new BRLActionVariableColumn(null,
-                                                                             null,
+        final ActionInsertFact aif = new ActionInsertFact(factType);
+        final ActionFieldValue afv = new ActionFieldValue(field,
+                                                          "$var",
+                                                          DataType.TYPE_STRING);
+        afv.setNature(FieldNatureType.TYPE_VARIABLE);
+        aif.addFieldValue(afv);
+        brlAction.setDefinition(Collections.singletonList(aif));
+
+        BRLActionVariableColumn variableColumn = new BRLActionVariableColumn("$var",
+                                                                             DataType.TYPE_STRING,
                                                                              factType,
                                                                              field);
         brlAction.getChildColumns().add(variableColumn);
@@ -1143,6 +1169,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).deleteColumn(eq(condition));
         verify(modellerPresenter,
                times(1)).updateLinks();
+        checkDTSelectionsChangedEventFired(1);
     }
 
     @Test
@@ -1162,6 +1189,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).deleteColumn(eq(column));
         verify(modellerPresenter,
                times(1)).updateLinks();
+        checkDTSelectionsChangedEventFired(1);
     }
 
     @Test
@@ -1180,6 +1208,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(refreshAttributesPanelEvent,
                times(2)).fire(any(RefreshAttributesPanelEvent.class));
+        checkDTSelectionsChangedEventFired(1);
     }
 
     @Test
@@ -1347,6 +1376,8 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).deleteCell(rowRangeCaptor.capture(),
                                     columnIndexCaptor.capture());
 
+        checkDTSelectionsChangedEventFired(2);
+
         final Integer columnIndex = columnIndexCaptor.getValue();
         final GridData.Range rowRange = rowRangeCaptor.getValue();
         assertEquals(0,
@@ -1359,9 +1390,12 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
     @Test
     public void onDeleteSelectedCellsWithSelectionWithBooleanColumn() {
-        final AttributeCol52 column = new AttributeCol52() {{
-            setAttribute(RuleAttributeWidget.ENABLED_ATTR);
-        }};
+        final AttributeCol52 column = new AttributeCol52() {
+
+            {
+                setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+            }
+        };
         dtPresenter.appendColumn(column);
 
         final GridData uiModel = dtPresenter.getUiModel();
@@ -1373,13 +1407,17 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(synchronizer,
                never()).deleteCell(any(GridData.Range.class),
                                    any(Integer.class));
+        checkDTSelectionsChangedEventFired(1);
     }
 
     @Test
     public void onDeleteSelectedCellsWithSelectionsWithBooleanColumn() {
-        final AttributeCol52 column = new AttributeCol52() {{
-            setAttribute(RuleAttributeWidget.ENABLED_ATTR);
-        }};
+        final AttributeCol52 column = new AttributeCol52() {
+
+            {
+                setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+            }
+        };
         dtPresenter.appendColumn(column);
 
         final GridData uiModel = dtPresenter.getUiModel();
@@ -1399,6 +1437,8 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(synchronizer,
                never()).deleteCell(any(GridData.Range.class),
                                    eq(2));
+        checkDTSelectionsChangedEventFired(3);
+
         final GridCell<?> booleanCell = uiModel.getCell(0,
                                                         2);
         assertNotNull(booleanCell);
@@ -1425,9 +1465,12 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
     @Test
     public void onDeleteSelectedColumnsWithSelections() throws ModelSynchronizer.MoveColumnVetoException {
-        final AttributeCol52 column = new AttributeCol52() {{
-            setAttribute("attribute1");
-        }};
+        final AttributeCol52 column = new AttributeCol52() {
+
+            {
+                setAttribute("attribute1");
+            }
+        };
         dtPresenter.appendColumn(column);
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
@@ -1437,6 +1480,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(synchronizer,
                times(1)).deleteColumn(eq(column));
+        checkDTSelectionsChangedEventFired(2);
     }
 
     @Test
@@ -1461,6 +1505,8 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).deleteRow(eq(0));
         verify(synchronizer,
                times(1)).deleteRow(eq(1));
+
+        checkDTSelectionsChangedEventFired(4);
     }
 
     @Test
@@ -1599,4 +1645,104 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(gridLayer,
                times(1)).draw();
     }
+
+    @Test
+    public void testAddOnEnterPinnedModeCommand() {
+
+        final GuidedDecisionTableModellerView.Presenter parent = mock(GuidedDecisionTableModellerView.Presenter.class);
+        final Command command = mock(Command.class);
+
+        doReturn(parent).when(dtPresenter).getParent();
+
+        dtPresenter.addOnEnterPinnedModeCommand(command);
+
+        verify(parent).addOnEnterPinnedModeCommand(command);
+    }
+
+    @Test
+    public void testAddOnExitPinnedModeCommand() {
+
+        final GuidedDecisionTableModellerView.Presenter parent = mock(GuidedDecisionTableModellerView.Presenter.class);
+        final Command command = mock(Command.class);
+
+        doReturn(parent).when(dtPresenter).getParent();
+
+        dtPresenter.addOnExitPinnedModeCommand(command);
+
+        verify(parent).addOnExitPinnedModeCommand(command);
+    }
+
+    @Test
+    public void testRefreshView() {
+        final GuidedDecisionTableModellerView.Presenter parent = mock(GuidedDecisionTableModellerView.Presenter.class);
+        final Layer layer = mock(Layer.class);
+
+        doReturn(parent).when(dtPresenter).getParent();
+        doReturn(layer).when(view).getLayer();
+
+        dtPresenter.refreshView();
+
+        verify(parent).updateLinks();
+        verify(parent).refreshScrollPosition();
+        verify(layer).draw();
+    }
+
+    @Test
+    public void testInitialiseAccess() {
+
+        final GuidedDecisionTablePresenter.Access access = mock(GuidedDecisionTablePresenter.Access.class);
+
+        doReturn(access).when(dtPresenter).getAccess();
+        doReturn(true).when(dtPresenter).canEditColumns();
+
+        dtPresenter.initialiseAccess(true);
+
+        verify(access).setReadOnly(true);
+        verify(access).setHasEditableColumns(true);
+    }
+
+    @Test
+    public void testCanEditColumns() {
+
+        final String permission = WorkbenchFeatures.GUIDED_DECISION_TABLE_EDIT_COLUMNS;
+        final User user = mock(User.class);
+
+        doReturn(user).when(sessionInfo).getIdentity();
+
+        dtPresenter.canEditColumns();
+
+        verify(authorizationManager).authorize(permission, user);
+    }
+
+    @Test
+    public void testHasEditableColumns() {
+
+        final GuidedDecisionTablePresenter.Access access = mock(GuidedDecisionTablePresenter.Access.class);
+
+        doReturn(access).when(dtPresenter).getAccess();
+        doReturn(true).when(access).hasEditableColumns();
+
+        final boolean hasEditableColumns = dtPresenter.hasEditableColumns();
+
+        assertTrue(hasEditableColumns);
+    }
+
+    /*
+     * check that valid DT selections change events are fired the correct number of times for a test case
+     */
+    private void checkDTSelectionsChangedEventFired(int times) {
+        final ArgumentCaptor<DecisionTableSelectionsChangedEvent> dtSelectionsChangedEventCaptor = ArgumentCaptor.forClass(DecisionTableSelectionsChangedEvent.class);
+
+        verify(decisionTableSelectionsChangedEvent,
+               times(times)).fire(dtSelectionsChangedEventCaptor.capture());
+
+        final List<DecisionTableSelectionsChangedEvent> dtSelectionsChangedEvents = dtSelectionsChangedEventCaptor.getAllValues();
+
+        assertNotNull(dtSelectionsChangedEvents);
+        assertEquals(dtSelectionsChangedEvents.size(),
+                     times);
+        dtSelectionsChangedEvents.stream().map(DecisionTableSelectionsChangedEvent::getPresenter).forEach(p -> assertEquals("Invalid DecisionTableSelectionsChangedEvent detected.",
+                                                                                                                            p,
+                                                                                                                            dtPresenter));
+    }
 }
