@@ -465,7 +465,7 @@ public class ConditionColumnPluginTest {
 
     @Test
     public void testGetTitle() {
-        final String errorKey = GuidedDecisionTableErraiConstants.ConditionColumnPlugin_AddNewConditionSimpleColumn;
+        final String errorKey = GuidedDecisionTableErraiConstants.ConditionColumnPlugin_AddConditionColumn;
         final String errorMessage = "Title";
 
         when(translationService.format(errorKey)).thenReturn(errorMessage);
@@ -683,6 +683,22 @@ public class ConditionColumnPluginTest {
                      true);
     }
 
+    @Test
+    public void testIsHideColumn() {
+        plugin.isHideColumn();
+
+        verify(editingCol).isHideColumn();
+    }
+
+    @Test
+    public void testSetHideColumn() throws Exception {
+        final boolean hideColumn = false;
+
+        plugin.setHideColumn(hideColumn);
+
+        verify(editingCol).setHideColumn(hideColumn);
+    }
+
     private ConditionCol52 makeConditionCol52(final int constraintValueType,
                                               final String factField,
                                               final String fieldType,
